@@ -1,17 +1,23 @@
+import getpass
 import os
 
-import six
-
 import pytest
+import keyring
+from jaraco.context import suppress
 
 import wolframalpha
 
 
-if six.PY2:
-    collect_ignore = [
-        'wolframalpha/pmxbot.py',
-        'wolframalpha/test_pmxbot.py',
-    ]
+@suppress(Exception)
+def from_keyring():
+    return keyring.get_password('https://api.wolframalpha.com/', getpass.getuser())
+
+
+def from_env():
+    try:
+        return os.environ['WOLFRAMALPHA_API_KEY']
+    except KeyError:
+        pytest.skip("Need WOLFRAMALPHA_API_KEY in environment")
 
 
 @pytest.fixture(scope='session')
@@ -21,10 +27,7 @@ def API_key():
     with a WOLFRAMALPHA_API_KEY environment variable. Otherwise,
     skip them.
     """
-    try:
-        return os.environ['WOLFRAMALPHA_API_KEY']
-    except KeyError:
-        pytest.skip("Need WOLFRAMALPHA_API_KEY in environment")
+    return from_keyring() or from_env()
 
 
 @pytest.fixture(scope='session')
